"""gustaf/gustaf/segment.py.

Segment class to form inputs for `triangle` and `tetgenpy`.
"""
